Crate uv_metadata

Crate uv_metadata 

Read metadata from wheels and source distributions.

This module reads all fields exhaustively. The fields are defined in the Core metadata specification.

Enums

Error
The caller is responsible for attaching the path or url we failed to read.

Functions

find_archive_dist_info
Find the .dist-info directory in a zipped wheel.
read_archive_metadata
Given an archive, read the METADATA from the .dist-info directory.
read_flat_wheel_metadata
Read the ResolutionMetadata from an unzipped wheel.
read_metadata_async_seek
Read a wheel’s METADATA file from a zip file.
read_metadata_async_stream
Like read_metadata_async_seek, but doesn’t use seek.